# augment.signal

## AudioPadType

::: fastaudio.augment.signal.AudioPadType
    :docstring:
    :members:

## ResizeSignal

::: fastaudio.augment.signal.ResizeSignal
    :docstring:

## SignalShifter

::: fastaudio.augment.signal.SignalShifter
    :docstring:

## NoiseColor

::: fastaudio.augment.signal.NoiseColor
    :docstring:
    :members:

## AddNoise

::: fastaudio.augment.signal.AddNoise
    :docstring:

## ChangeVolume

::: fastaudio.augment.signal.ChangeVolume
    :docstring:

## SignalCutout

::: fastaudio.augment.signal.SignalCutout
    :docstring:

## SignalLoss

::: fastaudio.augment.signal.SignalLoss
    :docstring:

## DownmixMono

::: fastaudio.augment.signal.DownmixMono
    :docstring:
